@@ -13,8 +13,8 @@ func TestExecute(t *testing.T) {
 	}{
 		{
 			block: code.Block{
-				Code:     `puts "Hello, world!"`,
-				Language: "ruby",
+				Code:     `fn main() { println!("Hello, world!"); }`,
+				Language: code.Rust,
 			},
 			expected: code.Result{
 				Out:      "Hello, world!\n",
@@ -23,21 +23,11 @@ func TestExecute(t *testing.T) {
 		},
 		{
 			block: code.Block{
-				Code:     `puts "Hi, there!"`,
+				Code:     `puts "Hello, world!"`,
 				Language: "ruby",
 			},
 			expected: code.Result{
-				Out:      "Hi, there!\n",
-				ExitCode: 0,
-			},
-		},
-		{
-			block: code.Block{
-				Code:     `print "No new line"`,
-				Language: "ruby",
-			},
-			expected: code.Result{
-				Out:      "No new line",
+				Out:      "Hello, world!\n",
 				ExitCode: 0,
 			},
 		},
@@ -107,7 +97,8 @@ func main() {
 		}
 		r := code.Execute(tc.block)
 		if r.Out != tc.expected.Out {
-			t.Fatalf("invalid output, got %s, want %s", r.Out, tc.expected.Out)
+			t.Fatalf("invalid output for lang %s, got %s, want %s | %+v",
+				tc.block.Language, r.Out, tc.expected.Out, r)
 		}
 
 		if r.ExitCode != tc.expected.ExitCode {
